export class OverlayManager {
    _overlays: {};
    _active: string | null;
    _keyDownBound: (evt: any) => void;
    get active(): string | null;
    /**
     * @param {string} name - The name of the overlay that is registered.
     * @param {HTMLDivElement} element - The overlay's DOM element.
     * @param {function} [callerCloseMethod] - The method that, if present, calls
     *                   `OverlayManager.close` from the object registering the
     *                   overlay. Access to this method is necessary in order to
     *                   run cleanup code when e.g. the overlay is force closed.
     *                   The default is `null`.
     * @param {boolean} [canForceClose] - Indicates if opening the overlay closes
     *                  an active overlay. The default is `false`.
     * @returns {Promise} A promise that is resolved when the overlay has been
     *                    registered.
     */
    register(name: string, element: HTMLDivElement, callerCloseMethod?: Function | undefined, canForceClose?: boolean | undefined): Promise<any>;
    /**
     * @param {string} name - The name of the overlay that is unregistered.
     * @returns {Promise} A promise that is resolved when the overlay has been
     *                    unregistered.
     */
    unregister(name: string): Promise<any>;
    /**
     * @param {string} name - The name of the overlay that should be opened.
     * @returns {Promise} A promise that is resolved when the overlay has been
     *                    opened.
     */
    open(name: string): Promise<any>;
    /**
     * @param {string} name - The name of the overlay that should be closed.
     * @returns {Promise} A promise that is resolved when the overlay has been
     *                    closed.
     */
    close(name: string): Promise<any>;
    /**
     * @private
     */
    private _keyDown;
    /**
     * @private
     */
    private _closeThroughCaller;
}
//# sourceMappingURL=overlay_manager.d.ts.map