export type PasswordPromptOptions = {
    /**
     * - Name of the overlay for the overlay manager.
     */
    overlayName: string;
    /**
     * - Div container for the overlay.
     */
    container: HTMLDivElement;
    /**
     * - Label containing instructions for
     *   entering the password.
     */
    label: HTMLParagraphElement;
    /**
     * - Input field for entering the password.
     */
    input: HTMLInputElement;
    /**
     * - Button for submitting the
     *   password.
     */
    submitButton: HTMLButtonElement;
    /**
     * - Button for cancelling password
     *   entry.
     */
    cancelButton: HTMLButtonElement;
};
/**
 * @typedef {Object} PasswordPromptOptions
 * @property {string} overlayName - Name of the overlay for the overlay manager.
 * @property {HTMLDivElement} container - Div container for the overlay.
 * @property {HTMLParagraphElement} label - Label containing instructions for
 *                                          entering the password.
 * @property {HTMLInputElement} input - Input field for entering the password.
 * @property {HTMLButtonElement} submitButton - Button for submitting the
 *                                              password.
 * @property {HTMLButtonElement} cancelButton - Button for cancelling password
 *                                              entry.
 */
export class PasswordPrompt {
    /**
     * @param {PasswordPromptOptions} options
     * @param {OverlayManager} overlayManager - Manager for the viewer overlays.
     * @param {IL10n} l10n - Localization service.
     */
    constructor(options: PasswordPromptOptions, overlayManager: any, l10n?: any);
    overlayName: string;
    container: HTMLDivElement;
    label: HTMLParagraphElement;
    input: HTMLInputElement;
    submitButton: HTMLButtonElement;
    cancelButton: HTMLButtonElement;
    overlayManager: any;
    l10n: any;
    updateCallback: any;
    reason: any;
    open(): void;
    close(): void;
    verify(): void;
    setUpdateCallback(updateCallback: any, reason: any): void;
}
//# sourceMappingURL=password_prompt.d.ts.map