export type PDFCursorToolsOptions = {
    /**
     * - The document container.
     */
    container: HTMLDivElement;
    /**
     * - The application event bus.
     */
    eventBus: any;
    /**
     * - The cursor tool that will be enabled
     * on load; the constants from {CursorTool} should be used. The default value
     * is `CursorTool.SELECT`.
     */
    cursorToolOnLoad?: number | undefined;
};
export namespace CursorTool {
    const SELECT: number;
    const HAND: number;
    const ZOOM: number;
}
/**
 * @typedef {Object} PDFCursorToolsOptions
 * @property {HTMLDivElement} container - The document container.
 * @property {EventBus} eventBus - The application event bus.
 * @property {number} [cursorToolOnLoad] - The cursor tool that will be enabled
 *   on load; the constants from {CursorTool} should be used. The default value
 *   is `CursorTool.SELECT`.
 */
export class PDFCursorTools {
    /**
     * @param {PDFCursorToolsOptions} options
     */
    constructor({ container, eventBus, cursorToolOnLoad }: PDFCursorToolsOptions);
    container: HTMLDivElement;
    eventBus: any;
    active: number;
    activeBeforePresentationMode: number | null;
    handTool: GrabToPan;
    /**
     * @type {number} One of the values in {CursorTool}.
     */
    get activeTool(): number;
    /**
     * NOTE: This method is ignored while Presentation Mode is active.
     * @param {number} tool - The cursor mode that should be switched to,
     *                        must be one of the values in {CursorTool}.
     */
    switchTool(tool: number): void;
    /**
     * @private
     */
    private _dispatchEvent;
    /**
     * @private
     */
    private _addEventListeners;
}
import { GrabToPan } from "./grab_to_pan.js";
//# sourceMappingURL=pdf_cursor_tools.d.ts.map