export type PDFThumbnailViewOptions = {
    /**
     * - The viewer element.
     */
    container: HTMLDivElement;
    /**
     * - The thumbnail's unique ID (normally its number).
     */
    id: number;
    /**
     * - The page viewport.
     */
    defaultViewport: any;
    /**
     * -
     * A promise that is resolved with an {@link OptionalContentConfig} instance.
     * The default value is `null`.
     */
    optionalContentConfigPromise?: Promise<any> | undefined;
    /**
     * - The navigation/linking service.
     */
    linkService: any;
    /**
     * - The rendering queue object.
     */
    renderingQueue: any;
    checkSetImageDisabled: Function;
    /**
     * - Don't convert the
     * canvas thumbnails to images. This prevents `toDataURL` calls, but
     * increases the overall memory usage. The default value is `false`.
     */
    disableCanvasToImageConversion?: boolean | undefined;
    /**
     * - Localization service.
     */
    l10n: any;
};
/**
 * @implements {IRenderableView}
 */
export class PDFThumbnailView implements IRenderableView {
    static cleanup(): void;
    /**
     * @param {PDFThumbnailViewOptions} options
     */
    constructor({ container, id, defaultViewport, optionalContentConfigPromise, linkService, renderingQueue, checkSetImageDisabled, disableCanvasToImageConversion, l10n, }: PDFThumbnailViewOptions);
    id: number;
    renderingId: string;
    pageLabel: string | null;
    pdfPage: any;
    rotation: number;
    viewport: any;
    pdfPageRotate: any;
    _optionalContentConfigPromise: Promise<any> | null;
    linkService: any;
    renderingQueue: any;
    renderTask: any;
    renderingState: number;
    resume: (() => void) | null;
    _checkSetImageDisabled: Function;
    disableCanvasToImageConversion: boolean;
    pageWidth: any;
    pageHeight: any;
    pageRatio: number;
    canvasWidth: number;
    canvasHeight: number;
    scale: number;
    l10n: any;
    anchor: HTMLAnchorElement;
    div: HTMLDivElement;
    ring: HTMLDivElement;
    setPdfPage(pdfPage: any): void;
    reset(): void;
    update(rotation: any): void;
    /**
     * PLEASE NOTE: Most likely you want to use the `this.reset()` method,
     *              rather than calling this one directly.
     */
    cancelRendering(): void;
    /**
     * @private
     */
    private _getPageDrawContext;
    canvas: HTMLCanvasElement | undefined;
    /**
     * @private
     */
    private _convertCanvasToImage;
    image: HTMLImageElement | undefined;
    draw(): any;
    setImage(pageView: any): void;
    get _thumbPageTitle(): any;
    get _thumbPageCanvas(): any;
    /**
     * @param {string|null} label
     */
    setPageLabel(label: string | null): void;
}
//# sourceMappingURL=pdf_thumbnail_view.d.ts.map