export type SecondaryToolbarOptions = {
    /**
     * - Container for the secondary toolbar.
     */
    toolbar: HTMLDivElement;
    /**
     * - Button to toggle the visibility
     * of the secondary toolbar.
     */
    toggleButton: HTMLButtonElement;
    /**
     * - Container where all the
     * toolbar buttons are placed. The maximum height of the toolbar is controlled
     * dynamically by adjusting the 'max-height' CSS property of this DOM element.
     */
    toolbarButtonContainer: HTMLDivElement;
    /**
     * - Button for entering
     * presentation mode.
     */
    presentationModeButton: HTMLButtonElement;
    /**
     * - Button to open a file.
     */
    openFileButton: HTMLButtonElement;
    /**
     * - Button to print the document.
     */
    printButton: HTMLButtonElement;
    /**
     * - Button to download the
     * document.
     */
    downloadButton: HTMLButtonElement;
    /**
     * - Button to obtain a bookmark
     * link to the current location in the document.
     */
    viewBookmarkButton: HTMLLinkElement;
    /**
     * - Button to go to the first
     * page in the document.
     */
    firstPageButton: HTMLButtonElement;
    /**
     * - Button to go to the last page
     * in the document.
     */
    lastPageButton: HTMLButtonElement;
    /**
     * - Button to rotate the pages
     * clockwise.
     */
    pageRotateCwButton: HTMLButtonElement;
    /**
     * - Button to rotate the
     * pages counterclockwise.
     */
    pageRotateCcwButton: HTMLButtonElement;
    /**
     * - Button to enable the
     * select tool.
     */
    cursorSelectToolButton: HTMLButtonElement;
    /**
     * - Button to enable the
     * hand tool.
     */
    cursorHandToolButton: HTMLButtonElement;
    /**
     * - Button for opening
     * the document properties dialog.
     */
    documentPropertiesButton: HTMLButtonElement;
};
/**
 * @typedef {Object} SecondaryToolbarOptions
 * @property {HTMLDivElement} toolbar - Container for the secondary toolbar.
 * @property {HTMLButtonElement} toggleButton - Button to toggle the visibility
 *   of the secondary toolbar.
 * @property {HTMLDivElement} toolbarButtonContainer - Container where all the
 *   toolbar buttons are placed. The maximum height of the toolbar is controlled
 *   dynamically by adjusting the 'max-height' CSS property of this DOM element.
 * @property {HTMLButtonElement} presentationModeButton - Button for entering
 *   presentation mode.
 * @property {HTMLButtonElement} openFileButton - Button to open a file.
 * @property {HTMLButtonElement} printButton - Button to print the document.
 * @property {HTMLButtonElement} downloadButton - Button to download the
 *   document.
 * @property {HTMLLinkElement} viewBookmarkButton - Button to obtain a bookmark
 *   link to the current location in the document.
 * @property {HTMLButtonElement} firstPageButton - Button to go to the first
 *   page in the document.
 * @property {HTMLButtonElement} lastPageButton - Button to go to the last page
 *   in the document.
 * @property {HTMLButtonElement} pageRotateCwButton - Button to rotate the pages
 *   clockwise.
 * @property {HTMLButtonElement} pageRotateCcwButton - Button to rotate the
 *   pages counterclockwise.
 * @property {HTMLButtonElement} cursorSelectToolButton - Button to enable the
 *   select tool.
 * @property {HTMLButtonElement} cursorHandToolButton - Button to enable the
 *   hand tool.
 * @property {HTMLButtonElement} documentPropertiesButton - Button for opening
 *   the document properties dialog.
 */
export class SecondaryToolbar {
    /**
     * @param {SecondaryToolbarOptions} options
     * @param {HTMLDivElement} mainContainer
     * @param {EventBus} eventBus
     */
    constructor(options: SecondaryToolbarOptions, mainContainer: HTMLDivElement, eventBus: any);
    toolbar: HTMLDivElement;
    toggleButton: HTMLButtonElement;
    toolbarButtonContainer: HTMLDivElement;
    buttons: ({
        element: HTMLButtonElement;
        eventName: string;
        close: boolean;
        eventDetails?: undefined;
    } | {
        element: HTMLLinkElement;
        eventName: null;
        close: boolean;
        eventDetails?: undefined;
    } | {
        element: HTMLButtonElement;
        eventName: string;
        eventDetails: {
            tool: number;
            mode?: undefined;
        };
        close: boolean;
    } | {
        element: any;
        eventName: string;
        eventDetails: {
            mode: number;
            tool?: undefined;
        };
        close: boolean;
    })[];
    items: {
        firstPage: HTMLButtonElement;
        lastPage: HTMLButtonElement;
        pageRotateCw: HTMLButtonElement;
        pageRotateCcw: HTMLButtonElement;
    };
    mainContainer: HTMLDivElement;
    eventBus: any;
    opened: boolean;
    containerHeight: number | null;
    previousContainerHeight: any;
    /**
     * @type {boolean}
     */
    get isOpen(): boolean;
    setPageNumber(pageNumber: any): void;
    pageNumber: any;
    setPagesCount(pagesCount: any): void;
    pagesCount: any;
    reset(): void;
    _updateUIState(): void;
    _bindClickListeners(): void;
    _bindCursorToolsListener(buttons: any): void;
    _bindScrollModeListener(buttons: any): void;
    _bindSpreadModeListener(buttons: any): void;
    open(): void;
    close(): void;
    toggle(): void;
    /**
     * @private
     */
    private _setMaxHeight;
}
//# sourceMappingURL=secondary_toolbar.d.ts.map