export type ToolbarOptions = {
    /**
     * - Container for the secondary toolbar.
     */
    container: HTMLDivElement;
    /**
     * - Label that contains number of pages.
     */
    numPages: HTMLSpanElement;
    /**
     * - Control for display and user input
     * of the current page number.
     */
    pageNumber: HTMLInputElement;
    /**
     * - Container where scale
     * controls are placed. The width is adjusted on UI initialization.
     */
    scaleSelectContainer: HTMLSpanElement;
    /**
     * - Scale selection control.
     */
    scaleSelect: HTMLSelectElement;
    /**
     * - The item used to display
     * a non-predefined scale.
     */
    customScaleOption: HTMLOptionElement;
    /**
     * - Button to go to the previous page.
     */
    previous: HTMLButtonElement;
    /**
     * - Button to go to the next page.
     */
    next: HTMLButtonElement;
    /**
     * - Button to zoom in the pages.
     */
    zoomIn: HTMLButtonElement;
    /**
     * - Button to zoom out the pages.
     */
    zoomOut: HTMLButtonElement;
    /**
     * - Button to open find bar.
     */
    viewFind: HTMLButtonElement;
    /**
     * - Button to open a new document.
     */
    openFile: HTMLButtonElement;
    /**
     * - Button to switch to
     * presentation mode.
     */
    presentationModeButton: HTMLButtonElement;
    /**
     * - Button to download the document.
     */
    download: HTMLButtonElement;
    /**
     * - Element to link current url of
     * the page view.
     */
    viewBookmark: any;
};
/**
 * @typedef {Object} ToolbarOptions
 * @property {HTMLDivElement} container - Container for the secondary toolbar.
 * @property {HTMLSpanElement} numPages - Label that contains number of pages.
 * @property {HTMLInputElement} pageNumber - Control for display and user input
 *   of the current page number.
 * @property {HTMLSpanElement} scaleSelectContainer - Container where scale
 *   controls are placed. The width is adjusted on UI initialization.
 * @property {HTMLSelectElement} scaleSelect - Scale selection control.
 * @property {HTMLOptionElement} customScaleOption - The item used to display
 *   a non-predefined scale.
 * @property {HTMLButtonElement} previous - Button to go to the previous page.
 * @property {HTMLButtonElement} next - Button to go to the next page.
 * @property {HTMLButtonElement} zoomIn - Button to zoom in the pages.
 * @property {HTMLButtonElement} zoomOut - Button to zoom out the pages.
 * @property {HTMLButtonElement} viewFind - Button to open find bar.
 * @property {HTMLButtonElement} openFile - Button to open a new document.
 * @property {HTMLButtonElement} presentationModeButton - Button to switch to
 *   presentation mode.
 * @property {HTMLButtonElement} download - Button to download the document.
 * @property {HTMLAElement} viewBookmark - Element to link current url of
 *   the page view.
 */
export class Toolbar {
    /**
     * @param {ToolbarOptions} options
     * @param {EventBus} eventBus
     * @param {IL10n} l10n - Localization service.
     */
    constructor(options: ToolbarOptions, eventBus: any, l10n?: any);
    toolbar: HTMLDivElement;
    eventBus: any;
    l10n: any;
    buttons: ({
        element: any;
        eventName: string;
    } | {
        element: any;
        eventName: null;
    })[];
    items: {
        numPages: HTMLSpanElement;
        pageNumber: HTMLInputElement;
        scaleSelectContainer: HTMLSpanElement;
        scaleSelect: HTMLSelectElement;
        customScaleOption: HTMLOptionElement;
        previous: HTMLButtonElement;
        next: HTMLButtonElement;
        zoomIn: HTMLButtonElement;
        zoomOut: HTMLButtonElement;
    };
    _wasLocalized: boolean;
    setPageNumber(pageNumber: any, pageLabel: any): void;
    pageNumber: any;
    pageLabel: any;
    setPagesCount(pagesCount: any, hasPageLabels: any): void;
    pagesCount: any;
    hasPageLabels: any;
    setPageScale(pageScaleValue: any, pageScale: any): void;
    pageScaleValue: any;
    pageScale: any;
    reset(): void;
    _bindListeners(): void;
    _updateUIState(resetNumPages?: boolean): void;
    updateLoadingIndicatorState(loading?: boolean): void;
    /**
     * Increase the width of the zoom dropdown DOM element if, and only if, it's
     * too narrow to fit the *longest* of the localized strings.
     * @private
     */
    private _adjustScaleWidth;
}
//# sourceMappingURL=toolbar.d.ts.map